==> gnucash_1.8.10.orig.tar.gz: gnucash-1.8.10/src/register/ledger-core/split-register-model.h <==
/********************************************************************\
 * split-register-model.h -- split register model object            *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
 * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
 *                                                                  *
\********************************************************************/

#ifndef SPLIT_REGISTER_MODEL_H
#define SPLIT_REGISTER_MODEL_H

#include "table-model.h"

TableModel * gnc_split_register_model_new (void);
TableModel * gnc_template_register_model_new (void);

#endif

==> gnucash_2.2.6.orig.tar.gz: gnucash-2.2.6/src/register/ledger-core/split-register-model.h <==
/********************************************************************\
 * split-register-model.h -- split register model object            *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 *                                                                  *
\********************************************************************/

#ifndef SPLIT_REGISTER_MODEL_H
#define SPLIT_REGISTER_MODEL_H

#include "table-model.h"

TableModel * gnc_split_register_model_new (void);
TableModel * gnc_template_register_model_new (void);

typedef enum {
  COLOR_UNKNOWN,
  COLOR_HEADER,
  COLOR_PRIMARY,
  COLOR_PRIMARY_ACTIVE,
  COLOR_SECONDARY,
  COLOR_SECONDARY_ACTIVE,
  COLOR_SPLIT,
  COLOR_SPLIT_ACTIVE,
} RegisterColor;

#endif
